%define upstream_name    Eval-Closure
%define upstream_version 0.14

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 3

Summary:    Safely and cleanly create closures via string eval
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        http://search.cpan.org/dist/%{upstream_name}
Source0:    http://www.cpan.org/modules/by-module/Eval/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(B)
BuildRequires: perl(Carp)
BuildRequires: perl(Exporter)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Spec)
BuildRequires: perl(IO::Handle)
BuildRequires: perl(IPC::Open3)
BuildRequires: perl(Scalar::Util)
BuildRequires: perl(Test::Fatal)
BuildRequires: perl(Test::More) >= 0.880.0
BuildRequires: perl(Test::Requires)
BuildRequires: perl(blib) >= 1.10.0
BuildRequires: perl(constant)
BuildRequires: perl(overload)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%{?perl_default_filter}

%description
String eval is often used for dynamic code generation. For instance,
'Moose' uses it heavily, to generate inlined versions of accessors and
constructors, which speeds code up at runtime by a significant amount.
String eval is not without its issues however - it's difficult to control
the scope it's used in (which determines which variables are in scope
inside the eval), and it can be quite slow, especially if doing a large
number of evals.

This module attempts to solve both of those problems. It provides an
'eval_closure' function, which evals a string in a clean environment, other
than a fixed list of specified variables. It also caches the result of the
eval, so that doing repeated evals of the same source, even with a
different environment, will be much faster (but note that the description
is part of the string to be evaled, so it must also be the same (or
non-existent) if caching is to work properly).

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%__perl Makefile.PL INSTALLDIRS=vendor

%make

%check
%make test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README
%{_mandir}/man3/*
%{perl_vendorlib}/*

%changelog
* Wed Feb 12 2020 umeabot <umeabot> 0.140.0-3.mga8
+ Revision: 1504392
- Mageia 8 Mass Rebuild

* Thu Sep 20 2018 umeabot <umeabot> 0.140.0-2.mga7
+ Revision: 1283630
- Mageia 7 Mass Rebuild

* Sat Jul 22 2017 shlomif <shlomif> 0.140.0-1.mga7
+ Revision: 1128537
- update to 0.14

* Sun Jun 19 2016 pterjan <pterjan> 0.130.0-3.mga6
+ Revision: 1026935
- Rebuild for perl 5.22.2

* Fri Feb 19 2016 umeabot <umeabot> 0.130.0-2.mga6
+ Revision: 968611
- Mageia 6 Mass Rebuild

* Tue Jul 14 2015 sander85 <sander85> 0.130.0-1.mga6
+ Revision: 854114
- update to 0.13

* Wed Oct 15 2014 umeabot <umeabot> 0.110.0-4.mga5
+ Revision: 746036
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 0.110.0-3.mga5
+ Revision: 732098
- add exclude

* Tue Sep 16 2014 umeabot <umeabot> 0.110.0-2.mga5
+ Revision: 684648
- Mageia 5 Mass Rebuild

* Sun Feb 09 2014 sander85 <sander85> 0.110.0-1.mga5
+ Revision: 587321
- update to 0.11

* Fri Oct 18 2013 umeabot <umeabot> 0.80.0-3.mga4
+ Revision: 511394
- Mageia 4 Mass Rebuild

* Sun Jan 13 2013 umeabot <umeabot> 0.80.0-2.mga3
+ Revision: 366908
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Feb 23 2012 jquelin <jquelin> 0.80.0-1.mga2
+ Revision: 212859
- update to 0.08

* Wed Jun 15 2011 jquelin <jquelin> 0.60.0-1.mga2
+ Revision: 106933
- update to 0.06

* Tue Apr 19 2011 jquelin <jquelin> 0.40.0-1.mga1
+ Revision: 88517
- update to 0.04

* Wed Apr 13 2011 jquelin <jquelin> 0.30.0-1.mga1
+ Revision: 84246
- imported package perl-Eval-Closure


* Wed Apr 13 2011 cpan2dist 0.03-1mga
- initial mageia release, generated with cpan2dist
